@@ -1,7 +1,7 @@
 # See LICENSE.incore for details
 """Console script for riscv_ctg."""
 
-import click,os,shutil
+import click,os
 
 from riscv_ctg.log import logger
 from riscv_ctg.ctg import ctg
@@ -17,16 +17,8 @@ from riscv_isac.cgf_normalize import expand_cgf
 @click.option('--procs','-p',type=int,default=1,help='Max number of processes to spawn')
 @click.option('--base-isa','-bi',type=click.Choice(['rv32e','rv32i','rv64i']),help="Base ISA string for the tests.")
 def cli(verbose, out_dir, randomize , cgf,procs,base_isa):
-    logger.level(verbose)
-    logger.info('****** RISC-V Compliance Test Generator {0} *******'.format(__version__ ))
-    logger.info('Copyright (c) 2020, InCore Semiconductors Pvt. Ltd.')
-    logger.info('All Rights Reserved.')
     if not os.path.exists(out_dir):
         os.mkdir(out_dir)
-    logger.info("Copying env folder to Output directory.")
-    env_dir = os.path.join(out_dir,"env")
-    if not os.path.exists(env_dir):
-        shutil.copytree(env,env_dir)
     if '32' in base_isa:
         xlen = 32
     elif '64' in base_isa:
